@@ -3,10 +3,7 @@
 
 import click
 
-from .datatools.s3op import create_s3_cli
 
 @click.group(help="Aero's Core commandset")
 def cli():
     pass
-
-create_s3_cli(cli)
\ No newline at end of file
