@@ -9,7 +9,7 @@ class EnvironmentDecorator(StepDecorator):
     Step decorator to add or update environment variables prior to the execution of your step.
 
     The environment variables set with this decorator will be present during the execution of the
-    step both locally or on Batch.
+    step.
 
     To use, annotate your step as follows:
     ```
@@ -27,5 +27,5 @@ class EnvironmentDecorator(StepDecorator):
     name = 'environment'
     defaults = {'vars': {}}
 
-    def step_init(self, flow, graph, step, decos, environment, datastore, logger):
-        os.environ.update(self.attributes['vars'].items())
+    def runtime_step_cli(self, cli_args, retry_count, max_user_code_retries):
+        cli_args.env.update(self.attributes['vars'].items())
\ No newline at end of file
